@@ -1,4 +1,4 @@
-/* $Id: html.h,v 1.5 2001/12/06 15:31:58 ukai Exp $ */
+/* $Id: html.h,v 1.9 2002/10/10 16:59:33 ukai Exp $ */
 #ifndef _HTML_H
 #define _HTML_H
 #ifdef USE_SSL
@@ -69,6 +69,9 @@ typedef struct {
     char *ext;
     int compression;
     char *guess_type;
+#ifdef USE_SSL
+    char *ssl_certificate;
+#endif
 } URLFile;
 
 #define CMP_NOCOMPRESS   0
@@ -182,9 +185,19 @@ typedef struct {
 #define HTML_DOCTYPE    97
 #define HTML_NOFRAMES   98
 #define HTML_N_NOFRAMES 99
-
+#define HTML_SUP	100
+#define HTML_N_SUP	101
+#define HTML_SUB	102
+#define HTML_N_SUB	103
 
    /* pseudo tag */
+#define HTML_INTERNAL       106
+#define HTML_N_INTERNAL     107
+#define HTML_SELECT_INT     108
+#define HTML_N_SELECT_INT   109
+#define HTML_OPTION_INT     110
+#define HTML_TEXTAREA_INT   111
+#define HTML_N_TEXTAREA_INT 112
 #define HTML_TABLE_ALT      113
 #define HTML_RULE           114
 #define HTML_N_RULE         115
@@ -248,11 +261,16 @@ typedef struct {
 #define ATTR_START		40
 #define ATTR_SELECTED		41
 #define ATTR_LABEL		42
-#define ATTR_READONLY        43
+#define ATTR_READONLY		43
+#define ATTR_SHAPE		44
+#define ATTR_COORDS		45
+#define ATTR_ISMAP		46
 
 /* Internal attribute */
-#define ATTR_TOP_MARGIN        51
-#define ATTR_BOTTOM_MARGIN      52
+#define ATTR_XOFFSET		49
+#define ATTR_YOFFSET		50
+#define ATTR_TOP_MARGIN		51
+#define ATTR_BOTTOM_MARGIN	52
 #define ATTR_TID		53
 #define ATTR_FID		54
 #define ATTR_FOR_TABLE		55
@@ -301,6 +319,12 @@ typedef struct tag_attribute_info {
 #define VTYPE_MLENGTH   9
 #define VTYPE_TYPE      10
 
+#define SHAPE_UNKNOWN	0
+#define SHAPE_DEFAULT	1
+#define SHAPE_RECT	2
+#define SHAPE_CIRCLE	3
+#define SHAPE_POLY	4
+
 extern TagInfo TagMAP[];
 extern TagAttrInfo AttrMAP[];
 
