@@ -1,4 +1,4 @@
-/* $Id: indep.c,v 1.18 2001/12/14 17:10:54 ukai Exp $ */
+/* $Id: indep.c,v 1.24 2002/08/27 16:35:15 ukai Exp $ */
 #include "fm.h"
 #include <stdio.h>
 #include <pwd.h>
@@ -11,6 +11,49 @@
 #include "myctype.h"
 #include "entity.h"
 
+clen_t
+strtoclen(const char *s)
+{
+#ifdef HAVE_STRTOLL
+    return strtoll(s, NULL, 10);
+#elif defined(HAVE_STRTOQ)
+    return strtoq(s, NULL, 10);
+#elif defined(HAVE_ATOLL)
+    return atoll(s);
+#elif defined(HAVE_ATOQ)
+    return atoq(s);
+#else
+    return atoi(s);
+#endif
+}
+
+#ifndef HAVE_BCOPY
+void
+bcopy(const void *src, void *dest, int len)
+{
+    int i;
+    if (src == dest)
+	return;
+    if (src < dest) {
+	for (i = len - 1; i >= 0; i--)
+	    ((char *)dest)[i] = ((const char *)src)[i];
+    }
+    else {			/* src > dest */
+	for (i = 0; i < len; i++)
+	    ((char *)dest)[i] = ((const char *)src)[i];
+    }
+}
+
+void
+bzero(void *ptr, int len)
+{
+    int i;
+    char *p = ptr;
+    for (i = 0; i < len; i++)
+	*(p++) = 0;
+}
+#endif				/* not HAVE_BCOPY */
+
 char *
 allocStr(const char *s, int len)
 {
@@ -166,6 +209,50 @@ expandPath(char *name)
     return extpath->ptr;
 }
 
+#ifndef HAVE_STRCHR
+char *
+strchr(const char *s, int c)
+{
+    while (*s) {
+	if ((unsigned char)*s == c)
+	    return (char *)s;
+	s++;
+    }
+    return NULL;
+}
+#endif				/* not HAVE_STRCHR */
+
+#ifndef HAVE_STRCASECMP
+int
+strcasecmp(const char *s1, const char *s2)
+{
+    int x;
+    while (*s1) {
+	x = tolower(*s1) - tolower(*s2);
+	if (x != 0)
+	    return x;
+	s1++;
+	s2++;
+    }
+    return -tolower(*s2);
+}
+
+int
+strncasecmp(const char *s1, const char *s2, size_t n)
+{
+    int x;
+    while (*s1 && n) {
+	x = tolower(*s1) - tolower(*s2);
+	if (x != 0)
+	    return x;
+	s1++;
+	s2++;
+	n--;
+    }
+    return n ? -tolower(*s2) : 0;
+}
+#endif				/* not HAVE_STRCASECMP */
+
 #ifndef HAVE_STRCASESTR
 /* string search using the simplest algorithm */
 char *
