@@ -1,6 +1,4 @@
-/* $Id: url.c,v 1.39.2.1 2002/02/04 16:26:29 ukai Exp $ */
-#include <stdio.h>
-#include "config.h"
+/* $Id: url.c,v 1.54 2002/11/04 08:47:38 ukai Exp $ */
 #include "fm.h"
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -278,7 +276,7 @@ init_PRNG()
 #endif				/* SSLEAY_VERSION_NUMBER >= 0x00905100 */
 
 static SSL *
-openSSLHandle(int sock, char *hostname)
+openSSLHandle(int sock, char *hostname, char **p_cert)
 {
     SSL *handle = NULL;
     static char *old_ssl_forbid_method = NULL;
@@ -364,8 +362,16 @@ openSSLHandle(int sock, char *hostname)
 #if SSLEAY_VERSION_NUMBER >= 0x00905100
     init_PRNG();
 #endif				/* SSLEAY_VERSION_NUMBER >= 0x00905100 */
-    if (SSL_connect(handle) > 0)
-	return handle;
+    if (SSL_connect(handle) > 0) {
+	Str serv_cert = ssl_get_certificate(handle, hostname);
+	if (serv_cert) {
+	    *p_cert = serv_cert->ptr;
+	    return handle;
+	}
+	close(sock);
+	SSL_free(handle);
+	return NULL;
+    }
   eend:
     close(sock);
     if (handle)
@@ -1116,6 +1122,10 @@ _parsedURL2Str(ParsedURL *pu, int pass)
 #ifndef USE_W3MMAILER
     if (pu->scheme == SCM_MAILTO) {
 	Strcat_charp(tmp, pu->file);
+	if (pu->query) {
+	    Strcat_char(tmp, '?');
+	    Strcat_charp(tmp, pu->query);
+	}
 	return tmp;
     }
 #endif
@@ -1284,6 +1294,8 @@ HTTPrequest(ParsedURL *pu, ParsedURL *current, HRequest *hr, TextList *extra)
 {
     Str tmp;
     TextListItem *i;
+    int seen_www_auth = 0;
+    int seen_proxy_auth = 0;
 #ifdef USE_COOKIE
     Str cookie;
 #endif				/* USE_COOKIE */
@@ -1296,8 +1308,54 @@ HTTPrequest(ParsedURL *pu, ParsedURL *current, HRequest *hr, TextList *extra)
     else
 	Strcat_charp(tmp, otherinfo(pu, current, hr->referer));
     if (extra != NULL)
-	for (i = extra->first; i != NULL; i = i->next)
+	for (i = extra->first; i != NULL; i = i->next) {
+	    if (strncasecmp(i->ptr, "Authorization:",
+			    sizeof("Authorization:") - 1) == 0) {
+		seen_www_auth = 1;
+#ifdef USE_SSL
+		if (hr->command == HR_COMMAND_CONNECT)
+		    continue;
+#endif
+	    }
+	    if (strncasecmp(i->ptr, "Proxy-Authorization:",
+			    sizeof("Proxy-Authorization:") - 1) == 0) {
+		seen_proxy_auth = 1;
+#ifdef USE_SSL
+		if (pu->scheme == SCM_HTTPS
+			&& hr->command != HR_COMMAND_CONNECT)
+		    continue;
+#endif
+	    }
 	    Strcat_charp(tmp, i->ptr);
+	}
+
+    if (!seen_www_auth
+#ifdef USE_SSL
+	    && hr->command != HR_COMMAND_CONNECT
+#endif
+	    ) {
+	Str auth_cookie = find_auth_cookie(pu->host, pu->port, pu->file, NULL);
+	if (auth_cookie)
+	    Strcat_m_charp(tmp, "Authorization: ", auth_cookie->ptr,
+			   "\r\n", NULL);
+    }
+
+    if (!seen_proxy_auth && (hr->flag & HR_FLAG_PROXY)
+#ifdef USE_SSL
+	    && (pu->scheme != SCM_HTTPS
+		|| hr->command == HR_COMMAND_CONNECT)
+#endif
+	    ) {
+	ParsedURL *proxy_pu = schemeToProxy(pu->scheme);
+	Str auth_cookie = find_auth_cookie(
+		proxy_pu->host, proxy_pu->port, proxy_pu->file, NULL);
+	if (!auth_cookie && proxy_auth_cookie)
+	    auth_cookie = proxy_auth_cookie;
+	if (auth_cookie)
+	    Strcat_m_charp(tmp, "Proxy-Authorization: ", auth_cookie->ptr,
+			   "\r\n", NULL);
+    }
+
 #ifdef USE_COOKIE
     if (hr->command != HR_COMMAND_CONNECT &&
 	use_cookie && (cookie = find_cookie(pu))) {
@@ -1516,6 +1574,7 @@ openURL(char *url, ParsedURL *pu, ParsedURL *current,
 	if (non_null(FTP_proxy) &&
 	    !Do_not_use_proxy &&
 	    pu->host != NULL && !check_no_proxy(pu->host)) {
+	    hr->flag |= HR_FLAG_PROXY;
 	    sock = openSocket(FTP_proxy_parsed.host,
 			      schemetable[FTP_proxy_parsed.scheme].cmdname,
 			      FTP_proxy_parsed.port);
@@ -1545,10 +1604,12 @@ openURL(char *url, ParsedURL *pu, ParsedURL *current,
 	    !Do_not_use_proxy &&
 	    pu->host != NULL && !check_no_proxy(pu->host)) {
 	    char *save_label;
+	    hr->flag |= HR_FLAG_PROXY;
 #ifdef USE_SSL
 	    if (pu->scheme == SCM_HTTPS && *status == HTST_CONNECT) {
 		sock = ssl_socket_of(ouf->stream);
-		if (!(sslh = openSSLHandle(sock, pu->host))) {
+		if (!(sslh = openSSLHandle(sock, pu->host,
+				&uf.ssl_certificate))) {
 		    *status = HTST_MISSING;
 		    return uf;
 		}
@@ -1576,7 +1637,7 @@ openURL(char *url, ParsedURL *pu, ParsedURL *current,
 	    if (pu->scheme == SCM_HTTPS) {
 		if (*status == HTST_NORMAL) {
 		    hr->command = HR_COMMAND_CONNECT;
-		    tmp = HTTPrequest(pu, current, hr, NULL);
+		    tmp = HTTPrequest(pu, current, hr, extra_header);
 		    *status = HTST_CONNECT;
 		}
 		else {
@@ -1602,7 +1663,8 @@ openURL(char *url, ParsedURL *pu, ParsedURL *current,
 	    }
 #ifdef USE_SSL
 	    if (pu->scheme == SCM_HTTPS) {
-		if (!(sslh = openSSLHandle(sock, pu->host))) {
+		if (!(sslh = openSSLHandle(sock, pu->host,
+				&uf.ssl_certificate))) {
 		    *status = HTST_MISSING;
 		    return uf;
 		}
@@ -1619,6 +1681,17 @@ openURL(char *url, ParsedURL *pu, ParsedURL *current,
 		SSL_write(sslh, tmp->ptr, tmp->length);
 	    else
 		write(sock, tmp->ptr, tmp->length);
+#ifdef HTTP_DEBUG
+	    {
+		FILE *ff = fopen("zzrequest", "a");
+		if (sslh)
+		    fputs("HTTPS: request via SSL\n", ff);
+		else
+		    fputs("HTTPS: request without SSL\n", ff);
+		fwrite(tmp->ptr, sizeof(char), tmp->length, ff);
+		fclose(ff);
+	    }
+#endif				/* HTTP_DEBUG */
 	    if (hr->command == HR_COMMAND_POST &&
 		request->enctype == FORM_ENCTYPE_MULTIPART) {
 		if (sslh)
@@ -1649,6 +1722,7 @@ openURL(char *url, ParsedURL *pu, ParsedURL *current,
 	if (non_null(GOPHER_proxy) &&
 	    !Do_not_use_proxy &&
 	    pu->host != NULL && !check_no_proxy(pu->host)) {
+	    hr->flag |= HR_FLAG_PROXY;
 	    sock = openSocket(GOPHER_proxy_parsed.host,
 			      schemetable[GOPHER_proxy_parsed.scheme].cmdname,
 			      GOPHER_proxy_parsed.port);
@@ -1664,7 +1738,7 @@ openURL(char *url, ParsedURL *pu, ParsedURL *current,
 		return uf;
 	    if (pu->file == NULL)
 		pu->file = "1";
-	    tmp = Strnew_charp(pu->file);
+	    tmp = Strnew_charp(url_unquote(pu->file));
 	    Strcat_char(tmp, '\n');
 	}
 	write(sock, tmp->ptr, tmp->length);
@@ -1674,6 +1748,8 @@ openURL(char *url, ParsedURL *pu, ParsedURL *current,
     case SCM_NNTP:
 	/* nntp://<host>:<port>/<newsgroup-name>/<article-number> */
     case SCM_NEWS:
+        /* news:<newsgroup-name> XXX: not yet */
+        /* news:<unique>@<full_domain_name> */
 	if (pu->scheme == SCM_NNTP) {
 	    p = pu->host;
 	}
@@ -1728,6 +1804,9 @@ openURL(char *url, ParsedURL *pu, ParsedURL *current,
 	    fprintf(fw, "ARTICLE %s\r\n", p);
 	}
 	else {
+	    if (pu->file == NULL || *pu->file == '\0')
+		goto nntp_error;
+	    /* pu-file contains '@' => news:<message-id> */
 	    fprintf(fw, "ARTICLE <%s>\r\n", url_unquote(pu->file));
 	}
 	fflush(fw);
@@ -2075,15 +2154,21 @@ searchURIMethods(ParsedURL *pu)
     if (scheme == NULL)
 	return NULL;
 
+    /*
+     * RFC2396 3.1. Scheme Component
+     * For resiliency, programs interpreting URI should treat upper case
+     * letters as equivalent to lower case in scheme names (e.g., allow
+     * "HTTP" as well as "http").
+     */
     for (i = 0; (ump = urimethods[i]) != NULL; i++) {
 	for (; ump->item1 != NULL; ump++) {
-	    if (strcmp(ump->item1, scheme->ptr) == 0) {
+	    if (strcasecmp(ump->item1, scheme->ptr) == 0) {
 		return Sprintf(ump->item2, url_quote(url->ptr));
 	    }
 	}
     }
     for (ump = default_urimethods; ump->item1 != NULL; ump++) {
-	if (strcmp(ump->item1, scheme->ptr) == 0) {
+	if (strcasecmp(ump->item1, scheme->ptr) == 0) {
 	    return Sprintf(ump->item2, url_quote(url->ptr));
 	}
     }
@@ -2119,3 +2204,30 @@ chkExternalURIBuffer(Buffer *buf)
     }
 }
 #endif
+
+ParsedURL *
+schemeToProxy(int scheme)
+{
+    ParsedURL *pu = NULL;	/* for gcc */
+    switch (scheme) {
+	case SCM_HTTP:
+#ifdef USE_SSL
+	case SCM_HTTPS:
+#endif
+	    pu = &HTTP_proxy_parsed;
+	    break;
+	case SCM_FTP:
+	    pu = &FTP_proxy_parsed;
+	    break;
+#ifdef USE_GOPHER
+	case SCM_GOPHER:
+	    pu = &GOPHER_proxy_parsed;
+	    break;
+#endif
+#ifdef DEBUG
+	default:
+	    abort();
+#endif
+    }
+    return pu;
+}
